============
Installation
============

.. {# pkglts, glabpkg, replace glabpkg_dev

If you only want to use the package::

    $ activate myenv
    (myenv) $ conda install allen1989 -c revesansparole

.. #}
